==> libsettings-0.1.9.tar.gz: libsettings-0.1.9/setup.py <==
#!/usr/bin/env python
# Copyright (C) 2018 Swift Navigation Inc.
# Contact: <dev@swift-nav.com>
#
# This source is subject to the license found in the file 'LICENSE' which must
# be be distributed together with this source. All other rights reserved.
#
# THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
# EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.

from glob import glob
from setuptools import setup, Extension

import os, sys

CLASSIFIERS = [
  'Intended Audience :: Developers',
  'Intended Audience :: Science/Research',
#  'Operating System :: POSIX :: Linux',
  'Operating System :: MacOS :: MacOS X',
  'Operating System :: Microsoft :: Windows',
  'Programming Language :: Python',
  'Topic :: Scientific/Engineering :: Interface Engine/Protocol Translator',
  'Topic :: Software Development :: Libraries :: Python Modules',
  'Programming Language :: Python :: 2.7',
  'Programming Language :: Python :: 3.4',
  'Programming Language :: Python :: 3.5',
  'Programming Language :: Python :: 3.6',
  'Programming Language :: Python :: 3.7',
]

PLATFORMS = [
  'linux',
  'osx',
  'win32',
]

include_dirs = ["include", "libsbp/c/include", "libswiftnav/include"]
sources = glob("python/*.pyx") + glob("src/*.c") + glob("libswiftnav/src/logging*.c") 

py_version = '{}{}'.format(sys.version_info[0], sys.version_info[1])

cflags = ["-Wno-unused-label", "-std=c99"]
ldflags = []
libraries = []

if os.name == 'nt':
    if py_version == '27' or py_version == '34':
      ldflags.append("-static-libgcc")
      libraries.append("python{}-gen".format(py_version))
    else:
       cflags = []

setup(
    name='libsettings',
    version="0.1.9",
    author="Swift Navigation",
    author_email="dev@swift-nav.com",
    description="Open source SwiftNav settings API library.",
    url="https://github.com/swift-nav/libsettings",
    classifiers=CLASSIFIERS,
    platforms=PLATFORMS,
    ext_modules=[
        Extension(
            'libsettings',
            sources,
            libraries=libraries,
            include_dirs=include_dirs,
            extra_compile_args=cflags,
            extra_link_args=ldflags,
        )
    ],
)

==> libsettings-0.1.11.tar.gz: libsettings-0.1.10/setup.py <==
#!/usr/bin/env python
# Copyright (C) 2018 Swift Navigation Inc.
# Contact: <dev@swift-nav.com>
#
# This source is subject to the license found in the file 'LICENSE' which must
# be be distributed together with this source. All other rights reserved.
#
# THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
# EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.

from glob import glob
from setuptools import setup, Extension

import os, sys

CLASSIFIERS = [
  'Intended Audience :: Developers',
  'Intended Audience :: Science/Research',
  'Operating System :: POSIX :: Linux',
  'Operating System :: MacOS :: MacOS X',
  'Operating System :: Microsoft :: Windows',
  'Programming Language :: Python',
  'Topic :: Scientific/Engineering :: Interface Engine/Protocol Translator',
  'Topic :: Software Development :: Libraries :: Python Modules',
  'Programming Language :: Python :: 2.7',
  'Programming Language :: Python :: 3.5',
  'Programming Language :: Python :: 3.6',
  'Programming Language :: Python :: 3.7',
]

PLATFORMS = [
  'linux',
  'osx',
  'win32',
]

include_dirs = ["include", "libsbp/c/include", "libswiftnav/include"]
sources = glob("python/*.pyx") + glob("src/*.c") + glob("libswiftnav/src/logging*.c") 

py_version = '{}{}'.format(sys.version_info[0], sys.version_info[1])

cflags = ["-Wno-unused-label", "-std=c99"]
ldflags = []
libraries = []

if os.name == 'nt':
    if py_version == '27' or py_version == '34':
        ldflags.append("-static-libgcc")
        libraries.append("python{}-gen".format(py_version))
    else:
        cflags = []

setup(
    name='libsettings',
    version="0.1.10",
    author="Swift Navigation",
    author_email="dev@swift-nav.com",
    description="Open source SwiftNav settings API library.",
    url="https://github.com/swift-nav/libsettings",
    classifiers=CLASSIFIERS,
    platforms=PLATFORMS,
    ext_modules=[
        Extension(
            'libsettings',
            sources,
            libraries=libraries,
            include_dirs=include_dirs,
            extra_compile_args=cflags,
            extra_link_args=ldflags,
        )
    ],
)
